State of health emailer — polyfemos 0.3.29 documentation

# State of health emailer

The state of health emailer (`main()`) can be used to notify about the problems with stations and parameters via email.

Only currently active alert (value=2) are reported. The date of the alertfile is selectable using an optional command line option, though.

## Configuration

The emailer is configured using a YAML file. The file is passed as a command line argument to the emailer.

Keys in the configuration file are:

from

The value is a string defining the email sender

    from: "soh.sender@example.com"

passwd

The value is a string defining the password of the sender’s email account.

    passwd: "***************"

to

The value is a list of string defining the email addresses of the recipients.

    to: [
      "some.recipient@example.com",
      ...
    ]

subject

The value is a string describing the email subject.

    subject: "State of Health alert"

alert_filepathformat

The value is a string defining the dynamic alertfile path. When defining the filepath format, it’s possible to use Reserved variables.

    alert_filepathformat: "~/polyfemos/data_out/FN/sohalerts/&YEAR/&NETWORK/&STATION/&NETWORK.&STATION.&YEAR.&JULDAY"

station_ids

The value is a list strings defining the selected station ids. Only alerts corresponding these stations will be reported.

    station_ids: [
      "FN.MSF",
      "FN.SGF",
      ...
    ]

sohpars

The value is a list strings defining the selected state of health parameters. Only alerts corresponding these parameters will be reported.

    sohpars:
      - "Digitizer_input_voltage"
      - "Data_realtimeness_HHZ"